==> haskell-gtk-strut-0.1.3.2-161-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-8B7tRVEhfji76wc4NXgdwb
key:                  gtk-strut-0.1.3.2-8B7tRVEhfji76wc4NXgdwb
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  063d04c2d7c71db3996f51a9a291a9f4
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-8B7tRVEhfji76wc4NXgdwb
depends:
    base-4.16.4.0 data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS
    gi-gdk-3.0.25-9kAhy6i1XX6FMwja1Gv6hT
    gi-gtk-3.0.38-GmyDXxVffhOCN0CHAHckHW
    hslogger-1.3.1.1-87j4TGmHnYt6TvQn3Et6fB text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk-strut-0.1.3.2-162-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk-strut.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk-strut
version:              0.1.3.2
visibility:           public
id:                   gtk-strut-0.1.3.2-GzDmElAWtz4A9kjEapTPGz
key:                  gtk-strut-0.1.3.2-GzDmElAWtz4A9kjEapTPGz
license:              BSD-3-Clause
copyright:            Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/gtk-strut#readme
synopsis:             Library for creating strut windows with gi-gtk
description:
    Please see the README on Github at <https://github.com/IvanMalison/gtk-strut#readme>

category:             System
abi:                  f6ad64ba580ed6d20cae0b4129d4b96b
exposed:              True
exposed-modules:      Graphics.UI.GIGtkStrut
hidden-modules:       Graphics.UI.EWMHStrut
import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk-strut-0.1.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk-strut
hs-libraries:         HSgtk-strut-0.1.3.2-GzDmElAWtz4A9kjEapTPGz
depends:
    base-4.16.4.0 data-default-0.7.1.1-KHhiQ7RPZneCNDFTFmFAYS
    gi-gdk-3.0.25-K9QMw2Bg06vA9lZd7ELWX2
    gi-gtk-3.0.38-J9661zdlhX3KVrEsGD2SCh
    hslogger-1.3.1.1-87j4TGmHnYt6TvQn3Et6fB text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gtk-strut/html/gtk-strut.haddock
haddock-html:         /usr/share/doc/haskell-gtk-strut/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
